Module: AdsCommon
- Defined in:
- lib/ads_common/utils.rb,
lib/ads_common/api.rb,
lib/ads_common/http.rb,
lib/ads_common/config.rb,
lib/ads_common/errors.rb,
lib/ads_common/version.rb,
lib/ads_common/api_config.rb,
lib/ads_common/savon_service.rb,
lib/ads_common/auth/base_handler.rb,
lib/ads_common/results_extractor.rb,
lib/ads_common/credential_handler.rb,
lib/ads_common/auth/oauth2_handler.rb,
lib/ads_common/build/savon_registry.rb,
lib/ads_common/parameters_validator.rb,
lib/ads_common/build/savon_generator.rb,
lib/ads_common/build/savon_service_generator.rb,
lib/ads_common/build/savon_abstract_generator.rb,
lib/ads_common/build/savon_registry_generator.rb,
lib/ads_common/savon_headers/base_header_handler.rb,
lib/ads_common/savon_headers/oauth_header_handler.rb,
lib/ads_common/auth/oauth2_service_account_handler.rb
Overview
- Copyright
Copyright 2012, Google Inc. All Rights Reserved.
- License
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
implied.
See the License for the specific language governing permissions and
limitations under the License.
This class extracts data received from Savon and enriches it.
Defined Under Namespace
Modules: ApiConfig, Auth, Build, Errors, SavonHeaders, Utils Classes: Api, Config, CredentialHandler, Http, ParametersValidator, ResultsExtractor, SavonService